HitchElasticSearch
==================

HitchElasticSearch is a plugin for the Hitch test framework that lets you run and
interact with Elastic Search in an isolated way as part of a test.

Use
===

See: https://hitchtest.readthedocs.org/en/latest/api/elasticsearch.html


.. _HitchServe: https://github.com/hitchtest/hitchserve
.. _DjangoRemindMe: https://github.com/hitchtest/django-remindme
